Documentation
¶
Index ¶
- Constants
- Variables
- func RegisterRoleServiceHTTPServer(hs *http.Server, srv RoleServiceHTTPServer)
- func RegisterRoleServiceServer(s grpc.ServiceRegistrar, srv RoleServiceServer)
- func RegisterUserServiceHTTPServer(hs *http.Server, srv UserServiceHTTPServer)
- func RegisterUserServiceServer(s grpc.ServiceRegistrar, srv UserServiceServer)
- type AssignRolesRequest
- func (*AssignRolesRequest) Descriptor() ([]byte, []int)deprecated
- func (x *AssignRolesRequest) GetBase() *base.Base
- func (x *AssignRolesRequest) GetId() uint32
- func (x *AssignRolesRequest) GetRoles() []*Role
- func (*AssignRolesRequest) ProtoMessage()
- func (x *AssignRolesRequest) ProtoReflect() protoreflect.Message
- func (x *AssignRolesRequest) Reset()
- func (x *AssignRolesRequest) String() string
- type AssignRolesResponse
- func (*AssignRolesResponse) Descriptor() ([]byte, []int)deprecated
- func (x *AssignRolesResponse) GetBaseResp() *base.BaseResp
- func (x *AssignRolesResponse) GetUser() *User
- func (*AssignRolesResponse) ProtoMessage()
- func (x *AssignRolesResponse) ProtoReflect() protoreflect.Message
- func (x *AssignRolesResponse) Reset()
- func (x *AssignRolesResponse) String() string
- type AuthenticateRequest
- func (*AuthenticateRequest) Descriptor() ([]byte, []int)deprecated
- func (x *AuthenticateRequest) GetAccount() string
- func (x *AuthenticateRequest) GetBase() *base.Base
- func (x *AuthenticateRequest) GetPassword() string
- func (*AuthenticateRequest) ProtoMessage()
- func (x *AuthenticateRequest) ProtoReflect() protoreflect.Message
- func (x *AuthenticateRequest) Reset()
- func (x *AuthenticateRequest) String() string
- type AuthenticateResponse
- func (*AuthenticateResponse) Descriptor() ([]byte, []int)deprecated
- func (x *AuthenticateResponse) GetBaseResp() *base.BaseResp
- func (x *AuthenticateResponse) GetUser() *User
- func (*AuthenticateResponse) ProtoMessage()
- func (x *AuthenticateResponse) ProtoReflect() protoreflect.Message
- func (x *AuthenticateResponse) Reset()
- func (x *AuthenticateResponse) String() string
- type CreateRoleRequest
- func (*CreateRoleRequest) Descriptor() ([]byte, []int)deprecated
- func (x *CreateRoleRequest) GetBase() *base.Base
- func (x *CreateRoleRequest) GetDescription() string
- func (x *CreateRoleRequest) GetName() string
- func (*CreateRoleRequest) ProtoMessage()
- func (x *CreateRoleRequest) ProtoReflect() protoreflect.Message
- func (x *CreateRoleRequest) Reset()
- func (x *CreateRoleRequest) String() string
- type CreateRoleResponse
- func (*CreateRoleResponse) Descriptor() ([]byte, []int)deprecated
- func (x *CreateRoleResponse) GetBaseResp() *base.BaseResp
- func (x *CreateRoleResponse) GetRole() *Role
- func (*CreateRoleResponse) ProtoMessage()
- func (x *CreateRoleResponse) ProtoReflect() protoreflect.Message
- func (x *CreateRoleResponse) Reset()
- func (x *CreateRoleResponse) String() string
- type CreateUserRequest
- func (*CreateUserRequest) Descriptor() ([]byte, []int)deprecated
- func (x *CreateUserRequest) GetBase() *base.Base
- func (x *CreateUserRequest) GetEmail() string
- func (x *CreateUserRequest) GetPassword() string
- func (x *CreateUserRequest) GetUsername() string
- func (*CreateUserRequest) ProtoMessage()
- func (x *CreateUserRequest) ProtoReflect() protoreflect.Message
- func (x *CreateUserRequest) Reset()
- func (x *CreateUserRequest) String() string
- type CreateUserResponse
- func (*CreateUserResponse) Descriptor() ([]byte, []int)deprecated
- func (x *CreateUserResponse) GetBaseResp() *base.BaseResp
- func (x *CreateUserResponse) GetId() uint32
- func (*CreateUserResponse) ProtoMessage()
- func (x *CreateUserResponse) ProtoReflect() protoreflect.Message
- func (x *CreateUserResponse) Reset()
- func (x *CreateUserResponse) String() string
- type DeleteRolesRequest
- func (*DeleteRolesRequest) Descriptor() ([]byte, []int)deprecated
- func (x *DeleteRolesRequest) GetBase() *base.Base
- func (x *DeleteRolesRequest) GetIds() []uint32
- func (*DeleteRolesRequest) ProtoMessage()
- func (x *DeleteRolesRequest) ProtoReflect() protoreflect.Message
- func (x *DeleteRolesRequest) Reset()
- func (x *DeleteRolesRequest) String() string
- type DeleteRolesResponse
- func (*DeleteRolesResponse) Descriptor() ([]byte, []int)deprecated
- func (x *DeleteRolesResponse) GetBaseResp() *base.BaseResp
- func (*DeleteRolesResponse) ProtoMessage()
- func (x *DeleteRolesResponse) ProtoReflect() protoreflect.Message
- func (x *DeleteRolesResponse) Reset()
- func (x *DeleteRolesResponse) String() string
- type GetRolesRequest
- type GetRolesResponse
- func (*GetRolesResponse) Descriptor() ([]byte, []int)deprecated
- func (x *GetRolesResponse) GetBaseResp() *base.BaseResp
- func (x *GetRolesResponse) GetRoles() []*Role
- func (*GetRolesResponse) ProtoMessage()
- func (x *GetRolesResponse) ProtoReflect() protoreflect.Message
- func (x *GetRolesResponse) Reset()
- func (x *GetRolesResponse) String() string
- type GetUserRequest
- func (*GetUserRequest) Descriptor() ([]byte, []int)deprecated
- func (x *GetUserRequest) GetBase() *base.Base
- func (x *GetUserRequest) GetId() uint32
- func (*GetUserRequest) ProtoMessage()
- func (x *GetUserRequest) ProtoReflect() protoreflect.Message
- func (x *GetUserRequest) Reset()
- func (x *GetUserRequest) String() string
- type GetUserResponse
- func (*GetUserResponse) Descriptor() ([]byte, []int)deprecated
- func (x *GetUserResponse) GetBaseResp() *base.BaseResp
- func (x *GetUserResponse) GetUser() *User
- func (*GetUserResponse) ProtoMessage()
- func (x *GetUserResponse) ProtoReflect() protoreflect.Message
- func (x *GetUserResponse) Reset()
- func (x *GetUserResponse) String() string
- type LoginRequest
- func (*LoginRequest) Descriptor() ([]byte, []int)deprecated
- func (x *LoginRequest) GetAccount() string
- func (x *LoginRequest) GetBase() *base.Base
- func (x *LoginRequest) GetPassword() string
- func (*LoginRequest) ProtoMessage()
- func (x *LoginRequest) ProtoReflect() protoreflect.Message
- func (x *LoginRequest) Reset()
- func (x *LoginRequest) String() string
- type LoginResponse
- func (*LoginResponse) Descriptor() ([]byte, []int)deprecated
- func (x *LoginResponse) GetBaseResp() *base.BaseResp
- func (x *LoginResponse) GetToken() string
- func (x *LoginResponse) GetTokenExpiresAt() int64
- func (x *LoginResponse) GetUser() *User
- func (*LoginResponse) ProtoMessage()
- func (x *LoginResponse) ProtoReflect() protoreflect.Message
- func (x *LoginResponse) Reset()
- func (x *LoginResponse) String() string
- type Role
- func (*Role) Descriptor() ([]byte, []int)deprecated
- func (x *Role) GetCreatedAt() int64
- func (x *Role) GetDescription() string
- func (x *Role) GetId() uint32
- func (x *Role) GetName() string
- func (x *Role) GetStatus() Role_Status
- func (x *Role) GetUpdatedAt() int64
- func (*Role) ProtoMessage()
- func (x *Role) ProtoReflect() protoreflect.Message
- func (x *Role) Reset()
- func (x *Role) String() string
- type RoleServiceClient
- type RoleServiceHTTPServer
- type RoleServiceServer
- type Role_Status
- func (Role_Status) Descriptor() protoreflect.EnumDescriptor
- func (x Role_Status) Enum() *Role_Status
- func (Role_Status) EnumDescriptor() ([]byte, []int)deprecated
- func (x Role_Status) Number() protoreflect.EnumNumber
- func (x Role_Status) String() string
- func (Role_Status) Type() protoreflect.EnumType
- type UnassignRolesRequest
- func (*UnassignRolesRequest) Descriptor() ([]byte, []int)deprecated
- func (x *UnassignRolesRequest) GetBase() *base.Base
- func (x *UnassignRolesRequest) GetId() uint32
- func (x *UnassignRolesRequest) GetRoles() []*Role
- func (*UnassignRolesRequest) ProtoMessage()
- func (x *UnassignRolesRequest) ProtoReflect() protoreflect.Message
- func (x *UnassignRolesRequest) Reset()
- func (x *UnassignRolesRequest) String() string
- type UnassignRolesResponse
- func (*UnassignRolesResponse) Descriptor() ([]byte, []int)deprecated
- func (x *UnassignRolesResponse) GetBaseResp() *base.BaseResp
- func (x *UnassignRolesResponse) GetUser() *User
- func (*UnassignRolesResponse) ProtoMessage()
- func (x *UnassignRolesResponse) ProtoReflect() protoreflect.Message
- func (x *UnassignRolesResponse) Reset()
- func (x *UnassignRolesResponse) String() string
- type UnimplementedRoleServiceServer
- func (UnimplementedRoleServiceServer) AssignRoles(context.Context, *AssignRolesRequest) (*AssignRolesResponse, error)
- func (UnimplementedRoleServiceServer) CreateRole(context.Context, *CreateRoleRequest) (*CreateRoleResponse, error)
- func (UnimplementedRoleServiceServer) DeleteRoles(context.Context, *DeleteRolesRequest) (*DeleteRolesResponse, error)
- func (UnimplementedRoleServiceServer) GetRoles(context.Context, *GetRolesRequest) (*GetRolesResponse, error)
- func (UnimplementedRoleServiceServer) UnassignRoles(context.Context, *UnassignRolesRequest) (*UnassignRolesResponse, error)
- func (UnimplementedRoleServiceServer) UpdateRole(context.Context, *UpdateRoleRequest) (*UpdateRoleResponse, error)
- type UnimplementedUserServiceServer
- func (UnimplementedUserServiceServer) Authenticate(context.Context, *AuthenticateRequest) (*AuthenticateResponse, error)
- func (UnimplementedUserServiceServer) CreateUser(context.Context, *CreateUserRequest) (*CreateUserResponse, error)
- func (UnimplementedUserServiceServer) GetUser(context.Context, *GetUserRequest) (*GetUserResponse, error)
- func (UnimplementedUserServiceServer) Login(context.Context, *LoginRequest) (*LoginResponse, error)
- func (UnimplementedUserServiceServer) UpdateUserPassword(context.Context, *UpdateUserPasswordRequest) (*UpdateUserPasswordResponse, error)
- func (UnimplementedUserServiceServer) UpdateUserStatus(context.Context, *UpdateUserStatusRequest) (*UpdateUserStatusResponse, error)
- type UnsafeRoleServiceServer
- type UnsafeUserServiceServer
- type UpdateRoleRequest
- func (*UpdateRoleRequest) Descriptor() ([]byte, []int)deprecated
- func (x *UpdateRoleRequest) GetBase() *base.Base
- func (x *UpdateRoleRequest) GetDescription() string
- func (x *UpdateRoleRequest) GetId() uint32
- func (x *UpdateRoleRequest) GetName() string
- func (*UpdateRoleRequest) ProtoMessage()
- func (x *UpdateRoleRequest) ProtoReflect() protoreflect.Message
- func (x *UpdateRoleRequest) Reset()
- func (x *UpdateRoleRequest) String() string
- type UpdateRoleResponse
- func (*UpdateRoleResponse) Descriptor() ([]byte, []int)deprecated
- func (x *UpdateRoleResponse) GetBaseResp() *base.BaseResp
- func (x *UpdateRoleResponse) GetRole() *Role
- func (*UpdateRoleResponse) ProtoMessage()
- func (x *UpdateRoleResponse) ProtoReflect() protoreflect.Message
- func (x *UpdateRoleResponse) Reset()
- func (x *UpdateRoleResponse) String() string
- type UpdateUserPasswordRequest
- func (*UpdateUserPasswordRequest) Descriptor() ([]byte, []int)deprecated
- func (x *UpdateUserPasswordRequest) GetBase() *base.Base
- func (x *UpdateUserPasswordRequest) GetId() uint32
- func (x *UpdateUserPasswordRequest) GetPassword() string
- func (*UpdateUserPasswordRequest) ProtoMessage()
- func (x *UpdateUserPasswordRequest) ProtoReflect() protoreflect.Message
- func (x *UpdateUserPasswordRequest) Reset()
- func (x *UpdateUserPasswordRequest) String() string
- type UpdateUserPasswordResponse
- func (*UpdateUserPasswordResponse) Descriptor() ([]byte, []int)deprecated
- func (x *UpdateUserPasswordResponse) GetBaseResp() *base.BaseResp
- func (*UpdateUserPasswordResponse) ProtoMessage()
- func (x *UpdateUserPasswordResponse) ProtoReflect() protoreflect.Message
- func (x *UpdateUserPasswordResponse) Reset()
- func (x *UpdateUserPasswordResponse) String() string
- type UpdateUserStatusRequest
- func (*UpdateUserStatusRequest) Descriptor() ([]byte, []int)deprecated
- func (x *UpdateUserStatusRequest) GetBase() *base.Base
- func (x *UpdateUserStatusRequest) GetId() uint32
- func (x *UpdateUserStatusRequest) GetStatus() User_Status
- func (*UpdateUserStatusRequest) ProtoMessage()
- func (x *UpdateUserStatusRequest) ProtoReflect() protoreflect.Message
- func (x *UpdateUserStatusRequest) Reset()
- func (x *UpdateUserStatusRequest) String() string
- type UpdateUserStatusResponse
- func (*UpdateUserStatusResponse) Descriptor() ([]byte, []int)deprecated
- func (x *UpdateUserStatusResponse) GetBaseResp() *base.BaseResp
- func (*UpdateUserStatusResponse) ProtoMessage()
- func (x *UpdateUserStatusResponse) ProtoReflect() protoreflect.Message
- func (x *UpdateUserStatusResponse) Reset()
- func (x *UpdateUserStatusResponse) String() string
- type User
- func (*User) Descriptor() ([]byte, []int)deprecated
- func (x *User) GetCreatedAt() int64
- func (x *User) GetEmail() string
- func (x *User) GetId() uint32
- func (x *User) GetLastLoginAt() int64
- func (x *User) GetRoles() []*Role
- func (x *User) GetStatus() User_Status
- func (x *User) GetUpdatedAt() int64
- func (x *User) GetUsername() string
- func (*User) ProtoMessage()
- func (x *User) ProtoReflect() protoreflect.Message
- func (x *User) Reset()
- func (x *User) String() string
- type UserServiceClient
- type UserServiceHTTPServer
- type UserServiceServer
- type User_Status
- func (User_Status) Descriptor() protoreflect.EnumDescriptor
- func (x User_Status) Enum() *User_Status
- func (User_Status) EnumDescriptor() ([]byte, []int)deprecated
- func (x User_Status) Number() protoreflect.EnumNumber
- func (x User_Status) String() string
- func (User_Status) Type() protoreflect.EnumType
Constants ¶
const ( RoleService_CreateRole_FullMethodName = "/identity.RoleService/CreateRole" RoleService_GetRoles_FullMethodName = "/identity.RoleService/GetRoles" RoleService_DeleteRoles_FullMethodName = "/identity.RoleService/DeleteRoles" RoleService_UpdateRole_FullMethodName = "/identity.RoleService/UpdateRole" RoleService_AssignRoles_FullMethodName = "/identity.RoleService/AssignRoles" RoleService_UnassignRoles_FullMethodName = "/identity.RoleService/UnassignRoles" )
const ( UserService_Login_FullMethodName = "/identity.UserService/Login" UserService_Authenticate_FullMethodName = "/identity.UserService/Authenticate" UserService_CreateUser_FullMethodName = "/identity.UserService/CreateUser" UserService_GetUser_FullMethodName = "/identity.UserService/GetUser" UserService_UpdateUserStatus_FullMethodName = "/identity.UserService/UpdateUserStatus" UserService_UpdateUserPassword_FullMethodName = "/identity.UserService/UpdateUserPassword" )
const OperationRoleServiceAssignRoles = "/RoleService/AssignRoles"
const OperationRoleServiceCreateRole = "/RoleService/CreateRole"
const OperationRoleServiceDeleteRoles = "/RoleService/DeleteRoles"
const OperationRoleServiceGetRoles = "/RoleService/GetRoles"
const OperationRoleServiceUnassignRoles = "/RoleService/UnassignRoles"
const OperationRoleServiceUpdateRole = "/RoleService/UpdateRole"
const OperationUserServiceCreateUser = "/UserService/CreateUser"
const OperationUserServiceGetUser = "/UserService/GetUser"
const OperationUserServiceLogin = "/UserService/Login"
const OperationUserServiceUpdateUserPassword = "/UserService/UpdateUserPassword"
const OperationUserServiceUpdateUserStatus = "/UserService/UpdateUserStatus"
const TRACER_NAME_ROLE = "github.com/dizzrt/dauth/api/gen/identity"
const TRACER_NAME_USER = "github.com/dizzrt/dauth/api/gen/identity"
Variables ¶
var ( Role_Status_name = map[int32]string{ 0: "UNSPECIFIED", 1: "ACTIVE", 2: "INACTIVE", 3: "DELETED", } Role_Status_value = map[string]int32{ "UNSPECIFIED": 0, "ACTIVE": 1, "INACTIVE": 2, "DELETED": 3, } )
Enum value maps for Role_Status.
var ( User_Status_name = map[int32]string{ 0: "UNSPECIFIED", 1: "ACTIVE", 2: "INACTIVE", 3: "DELETED", } User_Status_value = map[string]int32{ "UNSPECIFIED": 0, "ACTIVE": 1, "INACTIVE": 2, "DELETED": 3, } )
Enum value maps for User_Status.
var File_identity_identity_common_proto protoreflect.FileDescriptor
var File_identity_role_proto protoreflect.FileDescriptor
var File_identity_user_proto protoreflect.FileDescriptor
var RoleService_ServiceDesc = grpc.ServiceDesc{ ServiceName: "identity.RoleService", HandlerType: (*RoleServiceServer)(nil), Methods: []grpc.MethodDesc{ { MethodName: "CreateRole", Handler: _RoleService_CreateRole_Handler, }, { MethodName: "GetRoles", Handler: _RoleService_GetRoles_Handler, }, { MethodName: "DeleteRoles", Handler: _RoleService_DeleteRoles_Handler, }, { MethodName: "UpdateRole", Handler: _RoleService_UpdateRole_Handler, }, { MethodName: "AssignRoles", Handler: _RoleService_AssignRoles_Handler, }, { MethodName: "UnassignRoles", Handler: _RoleService_UnassignRoles_Handler, }, }, Streams: []grpc.StreamDesc{}, Metadata: "identity/role.proto", }
RoleService_ServiceDesc is the grpc.ServiceDesc for RoleService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)
var UserService_ServiceDesc = grpc.ServiceDesc{ ServiceName: "identity.UserService", HandlerType: (*UserServiceServer)(nil), Methods: []grpc.MethodDesc{ { MethodName: "Login", Handler: _UserService_Login_Handler, }, { MethodName: "Authenticate", Handler: _UserService_Authenticate_Handler, }, { MethodName: "CreateUser", Handler: _UserService_CreateUser_Handler, }, { MethodName: "GetUser", Handler: _UserService_GetUser_Handler, }, { MethodName: "UpdateUserStatus", Handler: _UserService_UpdateUserStatus_Handler, }, { MethodName: "UpdateUserPassword", Handler: _UserService_UpdateUserPassword_Handler, }, }, Streams: []grpc.StreamDesc{}, Metadata: "identity/user.proto", }
UserService_ServiceDesc is the grpc.ServiceDesc for UserService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)
Functions ¶
func RegisterRoleServiceHTTPServer ¶
func RegisterRoleServiceHTTPServer(hs *http.Server, srv RoleServiceHTTPServer)
func RegisterRoleServiceServer ¶
func RegisterRoleServiceServer(s grpc.ServiceRegistrar, srv RoleServiceServer)
func RegisterUserServiceHTTPServer ¶
func RegisterUserServiceHTTPServer(hs *http.Server, srv UserServiceHTTPServer)
func RegisterUserServiceServer ¶
func RegisterUserServiceServer(s grpc.ServiceRegistrar, srv UserServiceServer)
Types ¶
type AssignRolesRequest ¶
type AssignRolesRequest struct {
Id uint32 `protobuf:"varint,1,opt,name=id,proto3" json:"id,omitempty"`
Roles []*Role `protobuf:"bytes,2,rep,name=roles,proto3" json:"roles,omitempty"`
Base *base.Base `protobuf:"bytes,255,opt,name=base,proto3" json:"base,omitempty"`
// contains filtered or unexported fields
}
func (*AssignRolesRequest) Descriptor
deprecated
func (*AssignRolesRequest) Descriptor() ([]byte, []int)
Deprecated: Use AssignRolesRequest.ProtoReflect.Descriptor instead.
func (*AssignRolesRequest) GetBase ¶
func (x *AssignRolesRequest) GetBase() *base.Base
func (*AssignRolesRequest) GetId ¶
func (x *AssignRolesRequest) GetId() uint32
func (*AssignRolesRequest) GetRoles ¶
func (x *AssignRolesRequest) GetRoles() []*Role
func (*AssignRolesRequest) ProtoMessage ¶
func (*AssignRolesRequest) ProtoMessage()
func (*AssignRolesRequest) ProtoReflect ¶
func (x *AssignRolesRequest) ProtoReflect() protoreflect.Message
func (*AssignRolesRequest) Reset ¶
func (x *AssignRolesRequest) Reset()
func (*AssignRolesRequest) String ¶
func (x *AssignRolesRequest) String() string
type AssignRolesResponse ¶
type AssignRolesResponse struct {
User *User `protobuf:"bytes,1,opt,name=user,proto3" json:"user,omitempty"`
BaseResp *base.BaseResp `protobuf:"bytes,255,opt,name=base_resp,json=baseResp,proto3" json:"base_resp,omitempty"`
// contains filtered or unexported fields
}
func (*AssignRolesResponse) Descriptor
deprecated
func (*AssignRolesResponse) Descriptor() ([]byte, []int)
Deprecated: Use AssignRolesResponse.ProtoReflect.Descriptor instead.
func (*AssignRolesResponse) GetBaseResp ¶
func (x *AssignRolesResponse) GetBaseResp() *base.BaseResp
func (*AssignRolesResponse) GetUser ¶
func (x *AssignRolesResponse) GetUser() *User
func (*AssignRolesResponse) ProtoMessage ¶
func (*AssignRolesResponse) ProtoMessage()
func (*AssignRolesResponse) ProtoReflect ¶
func (x *AssignRolesResponse) ProtoReflect() protoreflect.Message
func (*AssignRolesResponse) Reset ¶
func (x *AssignRolesResponse) Reset()
func (*AssignRolesResponse) String ¶
func (x *AssignRolesResponse) String() string
type AuthenticateRequest ¶
type AuthenticateRequest struct {
Account string `protobuf:"bytes,1,opt,name=account,proto3" json:"account,omitempty"`
Password string `protobuf:"bytes,2,opt,name=password,proto3" json:"password,omitempty"`
Base *base.Base `protobuf:"bytes,255,opt,name=base,proto3" json:"base,omitempty"`
// contains filtered or unexported fields
}
func (*AuthenticateRequest) Descriptor
deprecated
func (*AuthenticateRequest) Descriptor() ([]byte, []int)
Deprecated: Use AuthenticateRequest.ProtoReflect.Descriptor instead.
func (*AuthenticateRequest) GetAccount ¶
func (x *AuthenticateRequest) GetAccount() string
func (*AuthenticateRequest) GetBase ¶
func (x *AuthenticateRequest) GetBase() *base.Base
func (*AuthenticateRequest) GetPassword ¶
func (x *AuthenticateRequest) GetPassword() string
func (*AuthenticateRequest) ProtoMessage ¶
func (*AuthenticateRequest) ProtoMessage()
func (*AuthenticateRequest) ProtoReflect ¶
func (x *AuthenticateRequest) ProtoReflect() protoreflect.Message
func (*AuthenticateRequest) Reset ¶
func (x *AuthenticateRequest) Reset()
func (*AuthenticateRequest) String ¶
func (x *AuthenticateRequest) String() string
type AuthenticateResponse ¶
type AuthenticateResponse struct {
User *User `protobuf:"bytes,1,opt,name=user,proto3" json:"user,omitempty"`
BaseResp *base.BaseResp `protobuf:"bytes,255,opt,name=base_resp,json=baseResp,proto3" json:"base_resp,omitempty"`
// contains filtered or unexported fields
}
func (*AuthenticateResponse) Descriptor
deprecated
func (*AuthenticateResponse) Descriptor() ([]byte, []int)
Deprecated: Use AuthenticateResponse.ProtoReflect.Descriptor instead.
func (*AuthenticateResponse) GetBaseResp ¶
func (x *AuthenticateResponse) GetBaseResp() *base.BaseResp
func (*AuthenticateResponse) GetUser ¶
func (x *AuthenticateResponse) GetUser() *User
func (*AuthenticateResponse) ProtoMessage ¶
func (*AuthenticateResponse) ProtoMessage()
func (*AuthenticateResponse) ProtoReflect ¶
func (x *AuthenticateResponse) ProtoReflect() protoreflect.Message
func (*AuthenticateResponse) Reset ¶
func (x *AuthenticateResponse) Reset()
func (*AuthenticateResponse) String ¶
func (x *AuthenticateResponse) String() string
type CreateRoleRequest ¶
type CreateRoleRequest struct {
Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
Description string `protobuf:"bytes,2,opt,name=description,proto3" json:"description,omitempty"`
Base *base.Base `protobuf:"bytes,255,opt,name=base,proto3" json:"base,omitempty"`
// contains filtered or unexported fields
}
func (*CreateRoleRequest) Descriptor
deprecated
func (*CreateRoleRequest) Descriptor() ([]byte, []int)
Deprecated: Use CreateRoleRequest.ProtoReflect.Descriptor instead.
func (*CreateRoleRequest) GetBase ¶
func (x *CreateRoleRequest) GetBase() *base.Base
func (*CreateRoleRequest) GetDescription ¶
func (x *CreateRoleRequest) GetDescription() string
func (*CreateRoleRequest) GetName ¶
func (x *CreateRoleRequest) GetName() string
func (*CreateRoleRequest) ProtoMessage ¶
func (*CreateRoleRequest) ProtoMessage()
func (*CreateRoleRequest) ProtoReflect ¶
func (x *CreateRoleRequest) ProtoReflect() protoreflect.Message
func (*CreateRoleRequest) Reset ¶
func (x *CreateRoleRequest) Reset()
func (*CreateRoleRequest) String ¶
func (x *CreateRoleRequest) String() string
type CreateRoleResponse ¶
type CreateRoleResponse struct {
Role *Role `protobuf:"bytes,1,opt,name=role,proto3" json:"role,omitempty"`
BaseResp *base.BaseResp `protobuf:"bytes,255,opt,name=base_resp,json=baseResp,proto3" json:"base_resp,omitempty"`
// contains filtered or unexported fields
}
func (*CreateRoleResponse) Descriptor
deprecated
func (*CreateRoleResponse) Descriptor() ([]byte, []int)
Deprecated: Use CreateRoleResponse.ProtoReflect.Descriptor instead.
func (*CreateRoleResponse) GetBaseResp ¶
func (x *CreateRoleResponse) GetBaseResp() *base.BaseResp
func (*CreateRoleResponse) GetRole ¶
func (x *CreateRoleResponse) GetRole() *Role
func (*CreateRoleResponse) ProtoMessage ¶
func (*CreateRoleResponse) ProtoMessage()
func (*CreateRoleResponse) ProtoReflect ¶
func (x *CreateRoleResponse) ProtoReflect() protoreflect.Message
func (*CreateRoleResponse) Reset ¶
func (x *CreateRoleResponse) Reset()
func (*CreateRoleResponse) String ¶
func (x *CreateRoleResponse) String() string
type CreateUserRequest ¶
type CreateUserRequest struct {
Email string `protobuf:"bytes,1,opt,name=email,proto3" json:"email,omitempty"`
Username string `protobuf:"bytes,2,opt,name=username,proto3" json:"username,omitempty"`
Password string `protobuf:"bytes,3,opt,name=password,proto3" json:"password,omitempty"`
Base *base.Base `protobuf:"bytes,255,opt,name=base,proto3" json:"base,omitempty"`
// contains filtered or unexported fields
}
func (*CreateUserRequest) Descriptor
deprecated
func (*CreateUserRequest) Descriptor() ([]byte, []int)
Deprecated: Use CreateUserRequest.ProtoReflect.Descriptor instead.
func (*CreateUserRequest) GetBase ¶
func (x *CreateUserRequest) GetBase() *base.Base
func (*CreateUserRequest) GetEmail ¶
func (x *CreateUserRequest) GetEmail() string
func (*CreateUserRequest) GetPassword ¶
func (x *CreateUserRequest) GetPassword() string
func (*CreateUserRequest) GetUsername ¶
func (x *CreateUserRequest) GetUsername() string
func (*CreateUserRequest) ProtoMessage ¶
func (*CreateUserRequest) ProtoMessage()
func (*CreateUserRequest) ProtoReflect ¶
func (x *CreateUserRequest) ProtoReflect() protoreflect.Message
func (*CreateUserRequest) Reset ¶
func (x *CreateUserRequest) Reset()
func (*CreateUserRequest) String ¶
func (x *CreateUserRequest) String() string
type CreateUserResponse ¶
type CreateUserResponse struct {
Id uint32 `protobuf:"varint,1,opt,name=id,proto3" json:"id,omitempty"`
BaseResp *base.BaseResp `protobuf:"bytes,255,opt,name=base_resp,json=baseResp,proto3" json:"base_resp,omitempty"`
// contains filtered or unexported fields
}
func (*CreateUserResponse) Descriptor
deprecated
func (*CreateUserResponse) Descriptor() ([]byte, []int)
Deprecated: Use CreateUserResponse.ProtoReflect.Descriptor instead.
func (*CreateUserResponse) GetBaseResp ¶
func (x *CreateUserResponse) GetBaseResp() *base.BaseResp
func (*CreateUserResponse) GetId ¶
func (x *CreateUserResponse) GetId() uint32
func (*CreateUserResponse) ProtoMessage ¶
func (*CreateUserResponse) ProtoMessage()
func (*CreateUserResponse) ProtoReflect ¶
func (x *CreateUserResponse) ProtoReflect() protoreflect.Message
func (*CreateUserResponse) Reset ¶
func (x *CreateUserResponse) Reset()
func (*CreateUserResponse) String ¶
func (x *CreateUserResponse) String() string
type DeleteRolesRequest ¶
type DeleteRolesRequest struct {
Ids []uint32 `protobuf:"varint,1,rep,packed,name=ids,proto3" json:"ids,omitempty"`
Base *base.Base `protobuf:"bytes,255,opt,name=base,proto3" json:"base,omitempty"`
// contains filtered or unexported fields
}
func (*DeleteRolesRequest) Descriptor
deprecated
func (*DeleteRolesRequest) Descriptor() ([]byte, []int)
Deprecated: Use DeleteRolesRequest.ProtoReflect.Descriptor instead.
func (*DeleteRolesRequest) GetBase ¶
func (x *DeleteRolesRequest) GetBase() *base.Base
func (*DeleteRolesRequest) GetIds ¶
func (x *DeleteRolesRequest) GetIds() []uint32
func (*DeleteRolesRequest) ProtoMessage ¶
func (*DeleteRolesRequest) ProtoMessage()
func (*DeleteRolesRequest) ProtoReflect ¶
func (x *DeleteRolesRequest) ProtoReflect() protoreflect.Message
func (*DeleteRolesRequest) Reset ¶
func (x *DeleteRolesRequest) Reset()
func (*DeleteRolesRequest) String ¶
func (x *DeleteRolesRequest) String() string
type DeleteRolesResponse ¶
type DeleteRolesResponse struct {
BaseResp *base.BaseResp `protobuf:"bytes,255,opt,name=base_resp,json=baseResp,proto3" json:"base_resp,omitempty"`
// contains filtered or unexported fields
}
func (*DeleteRolesResponse) Descriptor
deprecated
func (*DeleteRolesResponse) Descriptor() ([]byte, []int)
Deprecated: Use DeleteRolesResponse.ProtoReflect.Descriptor instead.
func (*DeleteRolesResponse) GetBaseResp ¶
func (x *DeleteRolesResponse) GetBaseResp() *base.BaseResp
func (*DeleteRolesResponse) ProtoMessage ¶
func (*DeleteRolesResponse) ProtoMessage()
func (*DeleteRolesResponse) ProtoReflect ¶
func (x *DeleteRolesResponse) ProtoReflect() protoreflect.Message
func (*DeleteRolesResponse) Reset ¶
func (x *DeleteRolesResponse) Reset()
func (*DeleteRolesResponse) String ¶
func (x *DeleteRolesResponse) String() string
type GetRolesRequest ¶
type GetRolesRequest struct {
Base *base.Base `protobuf:"bytes,255,opt,name=base,proto3" json:"base,omitempty"`
// contains filtered or unexported fields
}
func (*GetRolesRequest) Descriptor
deprecated
func (*GetRolesRequest) Descriptor() ([]byte, []int)
Deprecated: Use GetRolesRequest.ProtoReflect.Descriptor instead.
func (*GetRolesRequest) GetBase ¶
func (x *GetRolesRequest) GetBase() *base.Base
func (*GetRolesRequest) ProtoMessage ¶
func (*GetRolesRequest) ProtoMessage()
func (*GetRolesRequest) ProtoReflect ¶
func (x *GetRolesRequest) ProtoReflect() protoreflect.Message
func (*GetRolesRequest) Reset ¶
func (x *GetRolesRequest) Reset()
func (*GetRolesRequest) String ¶
func (x *GetRolesRequest) String() string
type GetRolesResponse ¶
type GetRolesResponse struct {
Roles []*Role `protobuf:"bytes,1,rep,name=roles,proto3" json:"roles,omitempty"`
BaseResp *base.BaseResp `protobuf:"bytes,255,opt,name=base_resp,json=baseResp,proto3" json:"base_resp,omitempty"`
// contains filtered or unexported fields
}
func (*GetRolesResponse) Descriptor
deprecated
func (*GetRolesResponse) Descriptor() ([]byte, []int)
Deprecated: Use GetRolesResponse.ProtoReflect.Descriptor instead.
func (*GetRolesResponse) GetBaseResp ¶
func (x *GetRolesResponse) GetBaseResp() *base.BaseResp
func (*GetRolesResponse) GetRoles ¶
func (x *GetRolesResponse) GetRoles() []*Role
func (*GetRolesResponse) ProtoMessage ¶
func (*GetRolesResponse) ProtoMessage()
func (*GetRolesResponse) ProtoReflect ¶
func (x *GetRolesResponse) ProtoReflect() protoreflect.Message
func (*GetRolesResponse) Reset ¶
func (x *GetRolesResponse) Reset()
func (*GetRolesResponse) String ¶
func (x *GetRolesResponse) String() string
type GetUserRequest ¶
type GetUserRequest struct {
Id uint32 `protobuf:"varint,1,opt,name=id,proto3" json:"id,omitempty"`
Base *base.Base `protobuf:"bytes,255,opt,name=base,proto3" json:"base,omitempty"`
// contains filtered or unexported fields
}
func (*GetUserRequest) Descriptor
deprecated
func (*GetUserRequest) Descriptor() ([]byte, []int)
Deprecated: Use GetUserRequest.ProtoReflect.Descriptor instead.
func (*GetUserRequest) GetBase ¶
func (x *GetUserRequest) GetBase() *base.Base
func (*GetUserRequest) GetId ¶
func (x *GetUserRequest) GetId() uint32
func (*GetUserRequest) ProtoMessage ¶
func (*GetUserRequest) ProtoMessage()
func (*GetUserRequest) ProtoReflect ¶
func (x *GetUserRequest) ProtoReflect() protoreflect.Message
func (*GetUserRequest) Reset ¶
func (x *GetUserRequest) Reset()
func (*GetUserRequest) String ¶
func (x *GetUserRequest) String() string
type GetUserResponse ¶
type GetUserResponse struct {
User *User `protobuf:"bytes,1,opt,name=user,proto3" json:"user,omitempty"`
BaseResp *base.BaseResp `protobuf:"bytes,255,opt,name=base_resp,json=baseResp,proto3" json:"base_resp,omitempty"`
// contains filtered or unexported fields
}
func (*GetUserResponse) Descriptor
deprecated
func (*GetUserResponse) Descriptor() ([]byte, []int)
Deprecated: Use GetUserResponse.ProtoReflect.Descriptor instead.
func (*GetUserResponse) GetBaseResp ¶
func (x *GetUserResponse) GetBaseResp() *base.BaseResp
func (*GetUserResponse) GetUser ¶
func (x *GetUserResponse) GetUser() *User
func (*GetUserResponse) ProtoMessage ¶
func (*GetUserResponse) ProtoMessage()
func (*GetUserResponse) ProtoReflect ¶
func (x *GetUserResponse) ProtoReflect() protoreflect.Message
func (*GetUserResponse) Reset ¶
func (x *GetUserResponse) Reset()
func (*GetUserResponse) String ¶
func (x *GetUserResponse) String() string
type LoginRequest ¶
type LoginRequest struct {
Account string `protobuf:"bytes,1,opt,name=account,proto3" json:"account,omitempty"`
Password string `protobuf:"bytes,2,opt,name=password,proto3" json:"password,omitempty"`
Base *base.Base `protobuf:"bytes,255,opt,name=base,proto3" json:"base,omitempty"`
// contains filtered or unexported fields
}
func (*LoginRequest) Descriptor
deprecated
func (*LoginRequest) Descriptor() ([]byte, []int)
Deprecated: Use LoginRequest.ProtoReflect.Descriptor instead.
func (*LoginRequest) GetAccount ¶
func (x *LoginRequest) GetAccount() string
func (*LoginRequest) GetBase ¶
func (x *LoginRequest) GetBase() *base.Base
func (*LoginRequest) GetPassword ¶
func (x *LoginRequest) GetPassword() string
func (*LoginRequest) ProtoMessage ¶
func (*LoginRequest) ProtoMessage()
func (*LoginRequest) ProtoReflect ¶
func (x *LoginRequest) ProtoReflect() protoreflect.Message
func (*LoginRequest) Reset ¶
func (x *LoginRequest) Reset()
func (*LoginRequest) String ¶
func (x *LoginRequest) String() string
type LoginResponse ¶
type LoginResponse struct {
User *User `protobuf:"bytes,1,opt,name=user,proto3" json:"user,omitempty"`
Token string `protobuf:"bytes,2,opt,name=token,proto3" json:"token,omitempty"`
TokenExpiresAt int64 `protobuf:"varint,3,opt,name=token_expires_at,json=tokenExpiresAt,proto3" json:"token_expires_at,omitempty"`
BaseResp *base.BaseResp `protobuf:"bytes,255,opt,name=base_resp,json=baseResp,proto3" json:"base_resp,omitempty"`
// contains filtered or unexported fields
}
func (*LoginResponse) Descriptor
deprecated
func (*LoginResponse) Descriptor() ([]byte, []int)
Deprecated: Use LoginResponse.ProtoReflect.Descriptor instead.
func (*LoginResponse) GetBaseResp ¶
func (x *LoginResponse) GetBaseResp() *base.BaseResp
func (*LoginResponse) GetToken ¶
func (x *LoginResponse) GetToken() string
func (*LoginResponse) GetTokenExpiresAt ¶
func (x *LoginResponse) GetTokenExpiresAt() int64
func (*LoginResponse) GetUser ¶
func (x *LoginResponse) GetUser() *User
func (*LoginResponse) ProtoMessage ¶
func (*LoginResponse) ProtoMessage()
func (*LoginResponse) ProtoReflect ¶
func (x *LoginResponse) ProtoReflect() protoreflect.Message
func (*LoginResponse) Reset ¶
func (x *LoginResponse) Reset()
func (*LoginResponse) String ¶
func (x *LoginResponse) String() string
type Role ¶
type Role struct {
Id uint32 `protobuf:"varint,1,opt,name=id,proto3" json:"id,omitempty"`
Name string `protobuf:"bytes,2,opt,name=name,proto3" json:"name,omitempty"`
Description string `protobuf:"bytes,3,opt,name=description,proto3" json:"description,omitempty"`
Status Role_Status `protobuf:"varint,4,opt,name=status,proto3,enum=identity.Role_Status" json:"status,omitempty"`
CreatedAt int64 `protobuf:"varint,5,opt,name=created_at,json=createdAt,proto3" json:"created_at,omitempty"`
UpdatedAt int64 `protobuf:"varint,6,opt,name=updated_at,json=updatedAt,proto3" json:"updated_at,omitempty"`
// contains filtered or unexported fields
}
func (*Role) Descriptor
deprecated
func (*Role) GetCreatedAt ¶
func (*Role) GetDescription ¶
func (*Role) GetStatus ¶
func (x *Role) GetStatus() Role_Status
func (*Role) GetUpdatedAt ¶
func (*Role) ProtoMessage ¶
func (*Role) ProtoMessage()
func (*Role) ProtoReflect ¶
func (x *Role) ProtoReflect() protoreflect.Message
type RoleServiceClient ¶
type RoleServiceClient interface {
// CreateRole creates a new role.
CreateRole(ctx context.Context, in *CreateRoleRequest, opts ...grpc.CallOption) (*CreateRoleResponse, error)
// GetRoles gets all roles.
GetRoles(ctx context.Context, in *GetRolesRequest, opts ...grpc.CallOption) (*GetRolesResponse, error)
// DeleteRoles deletes roles by IDs.
DeleteRoles(ctx context.Context, in *DeleteRolesRequest, opts ...grpc.CallOption) (*DeleteRolesResponse, error)
// UpdateRole updates a role by ID.
UpdateRole(ctx context.Context, in *UpdateRoleRequest, opts ...grpc.CallOption) (*UpdateRoleResponse, error)
// AssignRoles assigns roles to a user.
AssignRoles(ctx context.Context, in *AssignRolesRequest, opts ...grpc.CallOption) (*AssignRolesResponse, error)
// UnassignRoles unassigns roles from a user.
UnassignRoles(ctx context.Context, in *UnassignRolesRequest, opts ...grpc.CallOption) (*UnassignRolesResponse, error)
}
RoleServiceClient is the client API for RoleService service.
For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.
func NewRoleServiceClient ¶
func NewRoleServiceClient(cc grpc.ClientConnInterface) RoleServiceClient
type RoleServiceHTTPServer ¶
type RoleServiceHTTPServer interface {
// AssignRoles AssignRoles assigns roles to a user.
AssignRoles(context.Context, *AssignRolesRequest) (*AssignRolesResponse, error)
// CreateRole CreateRole creates a new role.
CreateRole(context.Context, *CreateRoleRequest) (*CreateRoleResponse, error)
// DeleteRoles DeleteRoles deletes roles by IDs.
DeleteRoles(context.Context, *DeleteRolesRequest) (*DeleteRolesResponse, error)
// GetRoles GetRoles gets all roles.
GetRoles(context.Context, *GetRolesRequest) (*GetRolesResponse, error)
// UnassignRoles UnassignRoles unassigns roles from a user.
UnassignRoles(context.Context, *UnassignRolesRequest) (*UnassignRolesResponse, error)
// UpdateRole UpdateRole updates a role by ID.
UpdateRole(context.Context, *UpdateRoleRequest) (*UpdateRoleResponse, error)
}
type RoleServiceServer ¶
type RoleServiceServer interface {
// CreateRole creates a new role.
CreateRole(context.Context, *CreateRoleRequest) (*CreateRoleResponse, error)
// GetRoles gets all roles.
GetRoles(context.Context, *GetRolesRequest) (*GetRolesResponse, error)
// DeleteRoles deletes roles by IDs.
DeleteRoles(context.Context, *DeleteRolesRequest) (*DeleteRolesResponse, error)
// UpdateRole updates a role by ID.
UpdateRole(context.Context, *UpdateRoleRequest) (*UpdateRoleResponse, error)
// AssignRoles assigns roles to a user.
AssignRoles(context.Context, *AssignRolesRequest) (*AssignRolesResponse, error)
// UnassignRoles unassigns roles from a user.
UnassignRoles(context.Context, *UnassignRolesRequest) (*UnassignRolesResponse, error)
// contains filtered or unexported methods
}
RoleServiceServer is the server API for RoleService service. All implementations must embed UnimplementedRoleServiceServer for forward compatibility.
type Role_Status ¶
type Role_Status int32
const ( Role_UNSPECIFIED Role_Status = 0 Role_ACTIVE Role_Status = 1 Role_INACTIVE Role_Status = 2 Role_DELETED Role_Status = 3 )
func (Role_Status) Descriptor ¶
func (Role_Status) Descriptor() protoreflect.EnumDescriptor
func (Role_Status) Enum ¶
func (x Role_Status) Enum() *Role_Status
func (Role_Status) EnumDescriptor
deprecated
func (Role_Status) EnumDescriptor() ([]byte, []int)
Deprecated: Use Role_Status.Descriptor instead.
func (Role_Status) Number ¶
func (x Role_Status) Number() protoreflect.EnumNumber
func (Role_Status) String ¶
func (x Role_Status) String() string
func (Role_Status) Type ¶
func (Role_Status) Type() protoreflect.EnumType
type UnassignRolesRequest ¶
type UnassignRolesRequest struct {
Id uint32 `protobuf:"varint,1,opt,name=id,proto3" json:"id,omitempty"`
Roles []*Role `protobuf:"bytes,2,rep,name=roles,proto3" json:"roles,omitempty"`
Base *base.Base `protobuf:"bytes,255,opt,name=base,proto3" json:"base,omitempty"`
// contains filtered or unexported fields
}
func (*UnassignRolesRequest) Descriptor
deprecated
func (*UnassignRolesRequest) Descriptor() ([]byte, []int)
Deprecated: Use UnassignRolesRequest.ProtoReflect.Descriptor instead.
func (*UnassignRolesRequest) GetBase ¶
func (x *UnassignRolesRequest) GetBase() *base.Base
func (*UnassignRolesRequest) GetId ¶
func (x *UnassignRolesRequest) GetId() uint32
func (*UnassignRolesRequest) GetRoles ¶
func (x *UnassignRolesRequest) GetRoles() []*Role
func (*UnassignRolesRequest) ProtoMessage ¶
func (*UnassignRolesRequest) ProtoMessage()
func (*UnassignRolesRequest) ProtoReflect ¶
func (x *UnassignRolesRequest) ProtoReflect() protoreflect.Message
func (*UnassignRolesRequest) Reset ¶
func (x *UnassignRolesRequest) Reset()
func (*UnassignRolesRequest) String ¶
func (x *UnassignRolesRequest) String() string
type UnassignRolesResponse ¶
type UnassignRolesResponse struct {
User *User `protobuf:"bytes,1,opt,name=user,proto3" json:"user,omitempty"`
BaseResp *base.BaseResp `protobuf:"bytes,255,opt,name=base_resp,json=baseResp,proto3" json:"base_resp,omitempty"`
// contains filtered or unexported fields
}
func (*UnassignRolesResponse) Descriptor
deprecated
func (*UnassignRolesResponse) Descriptor() ([]byte, []int)
Deprecated: Use UnassignRolesResponse.ProtoReflect.Descriptor instead.
func (*UnassignRolesResponse) GetBaseResp ¶
func (x *UnassignRolesResponse) GetBaseResp() *base.BaseResp
func (*UnassignRolesResponse) GetUser ¶
func (x *UnassignRolesResponse) GetUser() *User
func (*UnassignRolesResponse) ProtoMessage ¶
func (*UnassignRolesResponse) ProtoMessage()
func (*UnassignRolesResponse) ProtoReflect ¶
func (x *UnassignRolesResponse) ProtoReflect() protoreflect.Message
func (*UnassignRolesResponse) Reset ¶
func (x *UnassignRolesResponse) Reset()
func (*UnassignRolesResponse) String ¶
func (x *UnassignRolesResponse) String() string
type UnimplementedRoleServiceServer ¶
type UnimplementedRoleServiceServer struct{}
UnimplementedRoleServiceServer must be embedded to have forward compatible implementations.
NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.
func (UnimplementedRoleServiceServer) AssignRoles ¶
func (UnimplementedRoleServiceServer) AssignRoles(context.Context, *AssignRolesRequest) (*AssignRolesResponse, error)
func (UnimplementedRoleServiceServer) CreateRole ¶
func (UnimplementedRoleServiceServer) CreateRole(context.Context, *CreateRoleRequest) (*CreateRoleResponse, error)
func (UnimplementedRoleServiceServer) DeleteRoles ¶
func (UnimplementedRoleServiceServer) DeleteRoles(context.Context, *DeleteRolesRequest) (*DeleteRolesResponse, error)
func (UnimplementedRoleServiceServer) GetRoles ¶
func (UnimplementedRoleServiceServer) GetRoles(context.Context, *GetRolesRequest) (*GetRolesResponse, error)
func (UnimplementedRoleServiceServer) UnassignRoles ¶
func (UnimplementedRoleServiceServer) UnassignRoles(context.Context, *UnassignRolesRequest) (*UnassignRolesResponse, error)
func (UnimplementedRoleServiceServer) UpdateRole ¶
func (UnimplementedRoleServiceServer) UpdateRole(context.Context, *UpdateRoleRequest) (*UpdateRoleResponse, error)
type UnimplementedUserServiceServer ¶
type UnimplementedUserServiceServer struct{}
UnimplementedUserServiceServer must be embedded to have forward compatible implementations.
NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.
func (UnimplementedUserServiceServer) Authenticate ¶
func (UnimplementedUserServiceServer) Authenticate(context.Context, *AuthenticateRequest) (*AuthenticateResponse, error)
func (UnimplementedUserServiceServer) CreateUser ¶
func (UnimplementedUserServiceServer) CreateUser(context.Context, *CreateUserRequest) (*CreateUserResponse, error)
func (UnimplementedUserServiceServer) GetUser ¶
func (UnimplementedUserServiceServer) GetUser(context.Context, *GetUserRequest) (*GetUserResponse, error)
func (UnimplementedUserServiceServer) Login ¶
func (UnimplementedUserServiceServer) Login(context.Context, *LoginRequest) (*LoginResponse, error)
func (UnimplementedUserServiceServer) UpdateUserPassword ¶
func (UnimplementedUserServiceServer) UpdateUserPassword(context.Context, *UpdateUserPasswordRequest) (*UpdateUserPasswordResponse, error)
func (UnimplementedUserServiceServer) UpdateUserStatus ¶
func (UnimplementedUserServiceServer) UpdateUserStatus(context.Context, *UpdateUserStatusRequest) (*UpdateUserStatusResponse, error)
type UnsafeRoleServiceServer ¶
type UnsafeRoleServiceServer interface {
// contains filtered or unexported methods
}
UnsafeRoleServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to RoleServiceServer will result in compilation errors.
type UnsafeUserServiceServer ¶
type UnsafeUserServiceServer interface {
// contains filtered or unexported methods
}
UnsafeUserServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to UserServiceServer will result in compilation errors.
type UpdateRoleRequest ¶
type UpdateRoleRequest struct {
Id uint32 `protobuf:"varint,1,opt,name=id,proto3" json:"id,omitempty"`
Name string `protobuf:"bytes,2,opt,name=name,proto3" json:"name,omitempty"`
Description string `protobuf:"bytes,3,opt,name=description,proto3" json:"description,omitempty"`
Base *base.Base `protobuf:"bytes,255,opt,name=base,proto3" json:"base,omitempty"`
// contains filtered or unexported fields
}
func (*UpdateRoleRequest) Descriptor
deprecated
func (*UpdateRoleRequest) Descriptor() ([]byte, []int)
Deprecated: Use UpdateRoleRequest.ProtoReflect.Descriptor instead.
func (*UpdateRoleRequest) GetBase ¶
func (x *UpdateRoleRequest) GetBase() *base.Base
func (*UpdateRoleRequest) GetDescription ¶
func (x *UpdateRoleRequest) GetDescription() string
func (*UpdateRoleRequest) GetId ¶
func (x *UpdateRoleRequest) GetId() uint32
func (*UpdateRoleRequest) GetName ¶
func (x *UpdateRoleRequest) GetName() string
func (*UpdateRoleRequest) ProtoMessage ¶
func (*UpdateRoleRequest) ProtoMessage()
func (*UpdateRoleRequest) ProtoReflect ¶
func (x *UpdateRoleRequest) ProtoReflect() protoreflect.Message
func (*UpdateRoleRequest) Reset ¶
func (x *UpdateRoleRequest) Reset()
func (*UpdateRoleRequest) String ¶
func (x *UpdateRoleRequest) String() string
type UpdateRoleResponse ¶
type UpdateRoleResponse struct {
Role *Role `protobuf:"bytes,1,opt,name=role,proto3" json:"role,omitempty"`
BaseResp *base.BaseResp `protobuf:"bytes,255,opt,name=base_resp,json=baseResp,proto3" json:"base_resp,omitempty"`
// contains filtered or unexported fields
}
func (*UpdateRoleResponse) Descriptor
deprecated
func (*UpdateRoleResponse) Descriptor() ([]byte, []int)
Deprecated: Use UpdateRoleResponse.ProtoReflect.Descriptor instead.
func (*UpdateRoleResponse) GetBaseResp ¶
func (x *UpdateRoleResponse) GetBaseResp() *base.BaseResp
func (*UpdateRoleResponse) GetRole ¶
func (x *UpdateRoleResponse) GetRole() *Role
func (*UpdateRoleResponse) ProtoMessage ¶
func (*UpdateRoleResponse) ProtoMessage()
func (*UpdateRoleResponse) ProtoReflect ¶
func (x *UpdateRoleResponse) ProtoReflect() protoreflect.Message
func (*UpdateRoleResponse) Reset ¶
func (x *UpdateRoleResponse) Reset()
func (*UpdateRoleResponse) String ¶
func (x *UpdateRoleResponse) String() string
type UpdateUserPasswordRequest ¶
type UpdateUserPasswordRequest struct {
Id uint32 `protobuf:"varint,1,opt,name=id,proto3" json:"id,omitempty"`
Password string `protobuf:"bytes,2,opt,name=password,proto3" json:"password,omitempty"`
Base *base.Base `protobuf:"bytes,255,opt,name=base,proto3" json:"base,omitempty"`
// contains filtered or unexported fields
}
func (*UpdateUserPasswordRequest) Descriptor
deprecated
func (*UpdateUserPasswordRequest) Descriptor() ([]byte, []int)
Deprecated: Use UpdateUserPasswordRequest.ProtoReflect.Descriptor instead.
func (*UpdateUserPasswordRequest) GetBase ¶
func (x *UpdateUserPasswordRequest) GetBase() *base.Base
func (*UpdateUserPasswordRequest) GetId ¶
func (x *UpdateUserPasswordRequest) GetId() uint32
func (*UpdateUserPasswordRequest) GetPassword ¶
func (x *UpdateUserPasswordRequest) GetPassword() string
func (*UpdateUserPasswordRequest) ProtoMessage ¶
func (*UpdateUserPasswordRequest) ProtoMessage()
func (*UpdateUserPasswordRequest) ProtoReflect ¶
func (x *UpdateUserPasswordRequest) ProtoReflect() protoreflect.Message
func (*UpdateUserPasswordRequest) Reset ¶
func (x *UpdateUserPasswordRequest) Reset()
func (*UpdateUserPasswordRequest) String ¶
func (x *UpdateUserPasswordRequest) String() string
type UpdateUserPasswordResponse ¶
type UpdateUserPasswordResponse struct {
BaseResp *base.BaseResp `protobuf:"bytes,255,opt,name=base_resp,json=baseResp,proto3" json:"base_resp,omitempty"`
// contains filtered or unexported fields
}
func (*UpdateUserPasswordResponse) Descriptor
deprecated
func (*UpdateUserPasswordResponse) Descriptor() ([]byte, []int)
Deprecated: Use UpdateUserPasswordResponse.ProtoReflect.Descriptor instead.
func (*UpdateUserPasswordResponse) GetBaseResp ¶
func (x *UpdateUserPasswordResponse) GetBaseResp() *base.BaseResp
func (*UpdateUserPasswordResponse) ProtoMessage ¶
func (*UpdateUserPasswordResponse) ProtoMessage()
func (*UpdateUserPasswordResponse) ProtoReflect ¶
func (x *UpdateUserPasswordResponse) ProtoReflect() protoreflect.Message
func (*UpdateUserPasswordResponse) Reset ¶
func (x *UpdateUserPasswordResponse) Reset()
func (*UpdateUserPasswordResponse) String ¶
func (x *UpdateUserPasswordResponse) String() string
type UpdateUserStatusRequest ¶
type UpdateUserStatusRequest struct {
Id uint32 `protobuf:"varint,1,opt,name=id,proto3" json:"id,omitempty"`
Status User_Status `protobuf:"varint,2,opt,name=status,proto3,enum=identity.User_Status" json:"status,omitempty"`
Base *base.Base `protobuf:"bytes,255,opt,name=base,proto3" json:"base,omitempty"`
// contains filtered or unexported fields
}
func (*UpdateUserStatusRequest) Descriptor
deprecated
func (*UpdateUserStatusRequest) Descriptor() ([]byte, []int)
Deprecated: Use UpdateUserStatusRequest.ProtoReflect.Descriptor instead.
func (*UpdateUserStatusRequest) GetBase ¶
func (x *UpdateUserStatusRequest) GetBase() *base.Base
func (*UpdateUserStatusRequest) GetId ¶
func (x *UpdateUserStatusRequest) GetId() uint32
func (*UpdateUserStatusRequest) GetStatus ¶
func (x *UpdateUserStatusRequest) GetStatus() User_Status
func (*UpdateUserStatusRequest) ProtoMessage ¶
func (*UpdateUserStatusRequest) ProtoMessage()
func (*UpdateUserStatusRequest) ProtoReflect ¶
func (x *UpdateUserStatusRequest) ProtoReflect() protoreflect.Message
func (*UpdateUserStatusRequest) Reset ¶
func (x *UpdateUserStatusRequest) Reset()
func (*UpdateUserStatusRequest) String ¶
func (x *UpdateUserStatusRequest) String() string
type UpdateUserStatusResponse ¶
type UpdateUserStatusResponse struct {
BaseResp *base.BaseResp `protobuf:"bytes,255,opt,name=base_resp,json=baseResp,proto3" json:"base_resp,omitempty"`
// contains filtered or unexported fields
}
func (*UpdateUserStatusResponse) Descriptor
deprecated
func (*UpdateUserStatusResponse) Descriptor() ([]byte, []int)
Deprecated: Use UpdateUserStatusResponse.ProtoReflect.Descriptor instead.
func (*UpdateUserStatusResponse) GetBaseResp ¶
func (x *UpdateUserStatusResponse) GetBaseResp() *base.BaseResp
func (*UpdateUserStatusResponse) ProtoMessage ¶
func (*UpdateUserStatusResponse) ProtoMessage()
func (*UpdateUserStatusResponse) ProtoReflect ¶
func (x *UpdateUserStatusResponse) ProtoReflect() protoreflect.Message
func (*UpdateUserStatusResponse) Reset ¶
func (x *UpdateUserStatusResponse) Reset()
func (*UpdateUserStatusResponse) String ¶
func (x *UpdateUserStatusResponse) String() string
type User ¶
type User struct {
Id uint32 `protobuf:"varint,1,opt,name=id,proto3" json:"id,omitempty"`
Email string `protobuf:"bytes,2,opt,name=email,proto3" json:"email,omitempty"`
Username string `protobuf:"bytes,3,opt,name=username,proto3" json:"username,omitempty"`
Status User_Status `protobuf:"varint,4,opt,name=status,proto3,enum=identity.User_Status" json:"status,omitempty"`
Roles []*Role `protobuf:"bytes,5,rep,name=roles,proto3" json:"roles,omitempty"`
LastLoginAt int64 `protobuf:"varint,6,opt,name=last_login_at,json=lastLoginAt,proto3" json:"last_login_at,omitempty"`
CreatedAt int64 `protobuf:"varint,7,opt,name=created_at,json=createdAt,proto3" json:"created_at,omitempty"`
UpdatedAt int64 `protobuf:"varint,8,opt,name=updated_at,json=updatedAt,proto3" json:"updated_at,omitempty"`
// contains filtered or unexported fields
}
func (*User) Descriptor
deprecated
func (*User) GetCreatedAt ¶
func (*User) GetLastLoginAt ¶
func (*User) GetStatus ¶
func (x *User) GetStatus() User_Status
func (*User) GetUpdatedAt ¶
func (*User) GetUsername ¶
func (*User) ProtoMessage ¶
func (*User) ProtoMessage()
func (*User) ProtoReflect ¶
func (x *User) ProtoReflect() protoreflect.Message
type UserServiceClient ¶
type UserServiceClient interface {
// Login logs in a user.
Login(ctx context.Context, in *LoginRequest, opts ...grpc.CallOption) (*LoginResponse, error)
// Authenticate authenticates a user.
Authenticate(ctx context.Context, in *AuthenticateRequest, opts ...grpc.CallOption) (*AuthenticateResponse, error)
// CreateUser creates a new user.
CreateUser(ctx context.Context, in *CreateUserRequest, opts ...grpc.CallOption) (*CreateUserResponse, error)
// GetUser gets a user by ID.
GetUser(ctx context.Context, in *GetUserRequest, opts ...grpc.CallOption) (*GetUserResponse, error)
// UpdateUserStatus updates the status of a user.
UpdateUserStatus(ctx context.Context, in *UpdateUserStatusRequest, opts ...grpc.CallOption) (*UpdateUserStatusResponse, error)
// UpdateUserPassword updates the password of a user.
UpdateUserPassword(ctx context.Context, in *UpdateUserPasswordRequest, opts ...grpc.CallOption) (*UpdateUserPasswordResponse, error)
}
UserServiceClient is the client API for UserService service.
For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.
func NewUserServiceClient ¶
func NewUserServiceClient(cc grpc.ClientConnInterface) UserServiceClient
type UserServiceHTTPServer ¶
type UserServiceHTTPServer interface {
// CreateUser CreateUser creates a new user.
CreateUser(context.Context, *CreateUserRequest) (*CreateUserResponse, error)
// GetUser GetUser gets a user by ID.
GetUser(context.Context, *GetUserRequest) (*GetUserResponse, error)
// Login Login logs in a user.
Login(context.Context, *LoginRequest) (*LoginResponse, error)
// UpdateUserPassword UpdateUserPassword updates the password of a user.
UpdateUserPassword(context.Context, *UpdateUserPasswordRequest) (*UpdateUserPasswordResponse, error)
// UpdateUserStatus UpdateUserStatus updates the status of a user.
UpdateUserStatus(context.Context, *UpdateUserStatusRequest) (*UpdateUserStatusResponse, error)
}
type UserServiceServer ¶
type UserServiceServer interface {
// Login logs in a user.
Login(context.Context, *LoginRequest) (*LoginResponse, error)
// Authenticate authenticates a user.
Authenticate(context.Context, *AuthenticateRequest) (*AuthenticateResponse, error)
// CreateUser creates a new user.
CreateUser(context.Context, *CreateUserRequest) (*CreateUserResponse, error)
// GetUser gets a user by ID.
GetUser(context.Context, *GetUserRequest) (*GetUserResponse, error)
// UpdateUserStatus updates the status of a user.
UpdateUserStatus(context.Context, *UpdateUserStatusRequest) (*UpdateUserStatusResponse, error)
// UpdateUserPassword updates the password of a user.
UpdateUserPassword(context.Context, *UpdateUserPasswordRequest) (*UpdateUserPasswordResponse, error)
// contains filtered or unexported methods
}
UserServiceServer is the server API for UserService service. All implementations must embed UnimplementedUserServiceServer for forward compatibility.
type User_Status ¶
type User_Status int32
const ( User_UNSPECIFIED User_Status = 0 User_ACTIVE User_Status = 1 User_INACTIVE User_Status = 2 User_DELETED User_Status = 3 )
func (User_Status) Descriptor ¶
func (User_Status) Descriptor() protoreflect.EnumDescriptor
func (User_Status) Enum ¶
func (x User_Status) Enum() *User_Status
func (User_Status) EnumDescriptor
deprecated
func (User_Status) EnumDescriptor() ([]byte, []int)
Deprecated: Use User_Status.Descriptor instead.
func (User_Status) Number ¶
func (x User_Status) Number() protoreflect.EnumNumber
func (User_Status) String ¶
func (x User_Status) String() string
func (User_Status) Type ¶
func (User_Status) Type() protoreflect.EnumType