tokenconnect

package
v0.0.0-...-e07bab2 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jan 19, 2026 License: MIT Imports: 6 Imported by: 0

Documentation

Index

Constants

const (
	// TokenServiceIssueSSOTokenProcedure is the fully-qualified name of the TokenService's
	// IssueSSOToken RPC.
	TokenServiceIssueSSOTokenProcedure = "/token.TokenService/IssueSSOToken"
	// TokenServiceIssueProcedure is the fully-qualified name of the TokenService's Issue RPC.
	TokenServiceIssueProcedure = "/token.TokenService/Issue"
	// TokenServiceValidateProcedure is the fully-qualified name of the TokenService's Validate RPC.
	TokenServiceValidateProcedure = "/token.TokenService/Validate"
	// TokenServiceRevokeProcedure is the fully-qualified name of the TokenService's Revoke RPC.
	TokenServiceRevokeProcedure = "/token.TokenService/Revoke"
)

These constants are the fully-qualified names of the RPCs defined in this package. They're exposed at runtime as Spec.Procedure and as the final two segments of the HTTP route.

Note that these are different from the fully-qualified method names used by google.golang.org/protobuf/reflect/protoreflect. To convert from these constants to reflection-formatted method names, remove the leading slash and convert the remaining slash to a period.

const (
	// TokenServiceName is the fully-qualified name of the TokenService service.
	TokenServiceName = "token.TokenService"
)

Variables

This section is empty.

Functions

func NewTokenServiceHandler

func NewTokenServiceHandler(svc TokenServiceHandler, opts ...connect.HandlerOption) (string, http.Handler)

NewTokenServiceHandler builds an HTTP handler from the service implementation. It returns the path on which to mount the handler and the handler itself.

By default, handlers support the Connect, gRPC, and gRPC-Web protocols with the binary Protobuf and JSON codecs. They also support gzip compression.

Types

type TokenServiceClient

type TokenServiceClient interface {
	// IssueSSOToken issues a SSO token for the given uid.
	IssueSSOToken(context.Context, *connect.Request[token.IssueSSOTokenRequest]) (*connect.Response[token.IssueSSOTokenResponse], error)
	// Issue issues a token for the given uid and client_id.
	Issue(context.Context, *connect.Request[token.IssueRequest]) (*connect.Response[token.IssueResponse], error)
	// Validate validates a token.
	Validate(context.Context, *connect.Request[token.ValidateRequest]) (*connect.Response[token.ValidateResponse], error)
	// Revoke revokes a token.
	Revoke(context.Context, *connect.Request[token.RevokeRequest]) (*connect.Response[token.RevokeResponse], error)
}

TokenServiceClient is a client for the token.TokenService service.

func NewTokenServiceClient

func NewTokenServiceClient(httpClient connect.HTTPClient, baseURL string, opts ...connect.ClientOption) TokenServiceClient

NewTokenServiceClient constructs a client for the token.TokenService service. By default, it uses the Connect protocol with the binary Protobuf Codec, asks for gzipped responses, and sends uncompressed requests. To use the gRPC or gRPC-Web protocols, supply the connect.WithGRPC() or connect.WithGRPCWeb() options.

The URL supplied here should be the base URL for the Connect or gRPC server (for example, http://api.acme.com or https://acme.com/grpc).

type TokenServiceHandler

type TokenServiceHandler interface {
	// IssueSSOToken issues a SSO token for the given uid.
	IssueSSOToken(context.Context, *connect.Request[token.IssueSSOTokenRequest]) (*connect.Response[token.IssueSSOTokenResponse], error)
	// Issue issues a token for the given uid and client_id.
	Issue(context.Context, *connect.Request[token.IssueRequest]) (*connect.Response[token.IssueResponse], error)
	// Validate validates a token.
	Validate(context.Context, *connect.Request[token.ValidateRequest]) (*connect.Response[token.ValidateResponse], error)
	// Revoke revokes a token.
	Revoke(context.Context, *connect.Request[token.RevokeRequest]) (*connect.Response[token.RevokeResponse], error)
}

TokenServiceHandler is an implementation of the token.TokenService service.

type UnimplementedTokenServiceHandler

type UnimplementedTokenServiceHandler struct{}

UnimplementedTokenServiceHandler returns CodeUnimplemented from all methods.

Jump to